@@ -8,8 +8,8 @@
  * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
  */
 
-#ifndef _LIGHTDM_HOSTNAME_H_
-#define _LIGHTDM_HOSTNAME_H_
+#ifndef LIGHTDM_HOSTNAME_H_
+#define LIGHTDM_HOSTNAME_H_
 
 #include <glib-object.h>
 
@@ -17,6 +17,18 @@ G_BEGIN_DECLS
 
 const gchar *lightdm_get_hostname (void);
 
+const gchar *lightdm_get_os_id (void);
+
+const gchar *lightdm_get_os_name (void);
+
+const gchar *lightdm_get_os_pretty_name (void);
+
+const gchar *lightdm_get_os_version (void);
+
+const gchar *lightdm_get_os_version_id (void);
+
+gchar *lightdm_get_motd (void);
+
 G_END_DECLS
 
-#endif /* _LIGHTDM_HOSTNAME_H_ */
+#endif /* LIGHTDM_HOSTNAME_H_ */
