@@ -4,7 +4,7 @@
  * Copyright (C) 2014 Canonical, Ltd.
  * Authors: Robert Ancell <robert.ancell@canonical.com>
  *          Michael Terry <michael.terry@canonical.com>
- * 
+ *
  * This library is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by the Free
  * Software Foundation; either version 2 or version 3 of the License.
@@ -16,17 +16,58 @@
 #include "user-list.h"
 #include "lightdm/user.h"
 
+/**
+ * SECTION:user-list
+ * @short_description: Get information on user accounts on this system
+ * @include: lightdm.h
+ *
+ * An object that contains information about local user accounts.
+ */
+
+/**
+ * SECTION:user
+ * @short_description: Get information on a user account
+ * @include: lightdm.h
+ *
+ * Information about a local user account.
+ */
+
+/**
+ * LightDMUserList:
+ *
+ * #LightDMUserList is an opaque data structure and can only be accessed
+ * using the provided functions.
+ */
+
+/**
+ * LightDMUserListClass:
+ *
+ * Class structure for #LightDMUserList.
+ */
+
+/**
+ * LightDMUser:
+ *
+ * #LightDMUser is an opaque data structure and can only be accessed
+ * using the provided functions.
+ */
+
+/**
+ * LightDMUserClass:
+ *
+ * Class structure for #LightDMUser.
+ */
+
 enum
 {
-    LIST_PROP_0,
-    LIST_PROP_NUM_USERS,
+    LIST_PROP_NUM_USERS = 1,
+    LIST_PROP_LENGTH,  
     LIST_PROP_USERS,
 };
 
 enum
 {
-    USER_PROP_0,
-    USER_PROP_COMMON_USER,
+    USER_PROP_COMMON_USER = 1,
     USER_PROP_NAME,
     USER_PROP_REAL_NAME,
     USER_PROP_DISPLAY_NAME,
@@ -71,8 +112,8 @@ typedef struct
     CommonUser *common_user;
 } LightDMUserPrivate;
 
-G_DEFINE_TYPE (LightDMUserList, lightdm_user_list, G_TYPE_OBJECT);
-G_DEFINE_TYPE (LightDMUser, lightdm_user, G_TYPE_OBJECT);
+G_DEFINE_TYPE (LightDMUserList, lightdm_user_list, G_TYPE_OBJECT)
+G_DEFINE_TYPE (LightDMUser, lightdm_user, G_TYPE_OBJECT)
 
 #define GET_LIST_PRIVATE(obj) G_TYPE_INSTANCE_GET_PRIVATE ((obj), LIGHTDM_TYPE_USER_LIST, LightDMUserListPrivate)
 #define GET_USER_PRIVATE(obj) G_TYPE_INSTANCE_GET_PRIVATE ((obj), LIGHTDM_TYPE_USER, LightDMUserPrivate)
@@ -104,7 +145,7 @@ static LightDMUser *
 wrap_common_user (CommonUser *user)
 {
     LightDMUser *lightdm_user = g_object_new (LIGHTDM_TYPE_USER, "common-user", user, NULL);
-    g_signal_connect (user, "changed", G_CALLBACK (user_changed_cb), lightdm_user);
+    g_signal_connect (user, USER_SIGNAL_CHANGED, G_CALLBACK (user_changed_cb), lightdm_user);
     return lightdm_user;
 }
 
@@ -131,9 +172,8 @@ static void
 user_list_removed_cb (CommonUserList *common_list, CommonUser *common_user, LightDMUserList *user_list)
 {
     LightDMUserListPrivate *priv = GET_LIST_PRIVATE (user_list);
-    GList *link;
 
-    for (link = priv->lightdm_list; link; link = link->next)
+    for (GList *link = priv->lightdm_list; link; link = link->next)
     {
         LightDMUser *lightdm_user = link->data;
         LightDMUserPrivate *user_priv = GET_USER_PRIVATE (lightdm_user);
@@ -151,14 +191,12 @@ static void
 initialize_user_list_if_needed (LightDMUserList *user_list)
 {
     LightDMUserListPrivate *priv = GET_LIST_PRIVATE (user_list);
-    GList *common_users;
-    GList *link;
 
     if (priv->initialized)
         return;
 
-    common_users = common_user_list_get_users (common_user_list_get_instance ());
-    for (link = common_users; link; link = link->next)
+    GList *common_users = common_user_list_get_users (common_user_list_get_instance ());
+    for (GList *link = common_users; link; link = link->next)
     {
         CommonUser *user = link->data;
         LightDMUser *lightdm_user = wrap_common_user (user);
@@ -167,9 +205,9 @@ initialize_user_list_if_needed (LightDMUserList *user_list)
     priv->lightdm_list = g_list_reverse (priv->lightdm_list);
 
     CommonUserList *common_list = common_user_list_get_instance ();
-    g_signal_connect (common_list, "user-added", G_CALLBACK (user_list_added_cb), user_list);
-    g_signal_connect (common_list, "user-changed", G_CALLBACK (user_list_changed_cb), user_list);
-    g_signal_connect (common_list, "user-removed", G_CALLBACK (user_list_removed_cb), user_list);
+    g_signal_connect (common_list, USER_LIST_SIGNAL_USER_ADDED, G_CALLBACK (user_list_added_cb), user_list);
+    g_signal_connect (common_list, USER_LIST_SIGNAL_USER_CHANGED, G_CALLBACK (user_list_changed_cb), user_list);
+    g_signal_connect (common_list, USER_LIST_SIGNAL_USER_REMOVED, G_CALLBACK (user_list_removed_cb), user_list);
 
     priv->initialized = TRUE;
 }
@@ -210,21 +248,19 @@ lightdm_user_list_get_users (LightDMUserList *user_list)
  * @user_list: A #LightDMUserList
  * @username: Name of user to get.
  *
- * Get infomation about a given user or #NULL if this user doesn't exist.
+ * Get information about a given user or #NULL if this user doesn't exist.
  *
  * Return value: (transfer none): A #LightDMUser entry for the given user.
  **/
 LightDMUser *
 lightdm_user_list_get_user_by_name (LightDMUserList *user_list, const gchar *username)
 {
-    GList *link;
-
     g_return_val_if_fail (LIGHTDM_IS_USER_LIST (user_list), NULL);
     g_return_val_if_fail (username != NULL, NULL);
 
     initialize_user_list_if_needed (user_list);
 
-    for (link = GET_LIST_PRIVATE (user_list)->lightdm_list; link; link = link->next)
+    for (GList *link = GET_LIST_PRIVATE (user_list)->lightdm_list; link; link = link->next)
     {
         LightDMUser *user = link->data;
         if (g_strcmp0 (lightdm_user_get_name (user), username) == 0)
@@ -240,10 +276,10 @@ lightdm_user_list_init (LightDMUserList *user_list)
 }
 
 static void
-lightdm_user_list_set_property (GObject    *object,
-                                guint       prop_id,
+lightdm_user_list_set_property (GObject      *object,
+                                guint         prop_id,
                                 const GValue *value,
-                                GParamSpec *pspec)
+                                GParamSpec   *pspec)
 {
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 }
@@ -254,13 +290,12 @@ lightdm_user_list_get_property (GObject    *object,
                                 GValue     *value,
                                 GParamSpec *pspec)
 {
-    LightDMUserList *self;
-
-    self = LIGHTDM_USER_LIST (object);
+    LightDMUserList *self = LIGHTDM_USER_LIST (object);
 
     switch (prop_id)
     {
     case LIST_PROP_NUM_USERS:
+    case LIST_PROP_LENGTH:      
         g_value_set_int (value, lightdm_user_list_get_length (self));
         break;
     default:
@@ -297,16 +332,32 @@ lightdm_user_list_class_init (LightDMUserListClass *klass)
                                                        "num-users",
                                                        "Number of login users",
                                                        0, G_MAXINT, 0,
+                                                       G_PARAM_DEPRECATED | G_PARAM_READABLE));
+
+    g_object_class_install_property (object_class,
+                                     LIST_PROP_LENGTH,
+                                     g_param_spec_int ("length",
+                                                       "length",
+                                                       "Number of login users",
+                                                       0, G_MAXINT, 0,
                                                        G_PARAM_READABLE));
+
+    /*g_object_class_install_property (object_class,
+                                     LIST_PROP_USERS,
+                                     g_param_spec_int ("users",
+                                                       "users",
+                                                       "Users to present to user",
+                                                       0, G_MAXINT, 0,
+                                                       G_PARAM_READABLE));*/
     /**
      * LightDMUserList::user-added:
      * @user_list: A #LightDMUserList
-     * @user: The #LightDM user that has been added.
+     * @user: The #LightDMUser that has been added.
      *
      * The ::user-added signal gets emitted when a user account is created.
      **/
     list_signals[USER_ADDED] =
-        g_signal_new ("user-added",
+        g_signal_new (LIGHTDM_USER_LIST_SIGNAL_USER_ADDED,
                       G_TYPE_FROM_CLASS (klass),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMUserListClass, user_added),
@@ -317,12 +368,12 @@ lightdm_user_list_class_init (LightDMUserListClass *klass)
     /**
      * LightDMUserList::user-changed:
      * @user_list: A #LightDMUserList
-     * @user: The #LightDM user that has been changed.
+     * @user: The #LightDMUser that has been changed.
      *
      * The ::user-changed signal gets emitted when a user account is modified.
      **/
     list_signals[USER_CHANGED] =
-        g_signal_new ("user-changed",
+        g_signal_new (LIGHTDM_USER_LIST_SIGNAL_USER_CHANGED,
                       G_TYPE_FROM_CLASS (klass),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMUserListClass, user_changed),
@@ -333,12 +384,12 @@ lightdm_user_list_class_init (LightDMUserListClass *klass)
     /**
      * LightDMUserList::user-removed:
      * @user_list: A #LightDMUserList
-     * @user: The #LightDM user that has been removed.
+     * @user: The #LightDMUser that has been removed.
      *
      * The ::user-removed signal gets emitted when a user account is removed.
      **/
     list_signals[USER_REMOVED] =
-        g_signal_new ("user-removed",
+        g_signal_new (LIGHTDM_USER_LIST_SIGNAL_USER_REMOVED,
                       G_TYPE_FROM_CLASS (klass),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMUserListClass, user_removed),
@@ -350,9 +401,9 @@ lightdm_user_list_class_init (LightDMUserListClass *klass)
 /**
  * lightdm_user_get_name:
  * @user: A #LightDMUser
- * 
+ *
  * Get the name of a user.
- * 
+ *
  * Return value: The name of the given user
  **/
 const gchar *
@@ -365,7 +416,7 @@ lightdm_user_get_name (LightDMUser *user)
 /**
  * lightdm_user_get_real_name:
  * @user: A #LightDMUser
- * 
+ *
  * Get the real name of a user.
  *
  * Return value: The real name of the given user
@@ -380,9 +431,9 @@ lightdm_user_get_real_name (LightDMUser *user)
 /**
  * lightdm_user_get_display_name:
  * @user: A #LightDMUser
- * 
+ *
  * Get the display name of a user.
- * 
+ *
  * Return value: The display name of the given user
  **/
 const gchar *
@@ -395,9 +446,9 @@ lightdm_user_get_display_name (LightDMUser *user)
 /**
  * lightdm_user_get_home_directory:
  * @user: A #LightDMUser
- * 
+ *
  * Get the home directory for a user.
- * 
+ *
  * Return value: The users home directory
  */
 const gchar *
@@ -410,10 +461,10 @@ lightdm_user_get_home_directory (LightDMUser *user)
 /**
  * lightdm_user_get_image:
  * @user: A #LightDMUser
- * 
+ *
  * Get the image URI for a user.
- * 
- * Return value: The image URI for the given user or #NULL if no URI
+ *
+ * Return value: (nullable): The image URI for the given user or #NULL if no URI
  **/
 const gchar *
 lightdm_user_get_image (LightDMUser *user)
@@ -425,10 +476,10 @@ lightdm_user_get_image (LightDMUser *user)
 /**
  * lightdm_user_get_background:
  * @user: A #LightDMUser
- * 
+ *
  * Get the background file path for a user.
- * 
- * Return value: The background file path for the given user or #NULL if no path
+ *
+ * Return value: (nullable): The background file path for the given user or #NULL if no path
  **/
 const gchar *
 lightdm_user_get_background (LightDMUser *user)
@@ -440,10 +491,10 @@ lightdm_user_get_background (LightDMUser *user)
 /**
  * lightdm_user_get_language:
  * @user: A #LightDMUser
- * 
+ *
  * Get the language for a user.
- * 
- * Return value: The language in the form of a local specification (e.g. "de_DE.UTF-8") for the given user or #NULL if using the system default locale.
+ *
+ * Return value: (nullable): The language in the form of a local specification (e.g. "de_DE.UTF-8") for the given user or #NULL if using the system default locale.
  **/
 const gchar *
 lightdm_user_get_language (LightDMUser *user)
@@ -455,10 +506,10 @@ lightdm_user_get_language (LightDMUser *user)
 /**
  * lightdm_user_get_layout:
  * @user: A #LightDMUser
- * 
+ *
  * Get the keyboard layout for a user.
- * 
- * Return value: The keyboard layout for the given user or #NULL if using system defaults.  Copy the value if you want to use it long term.
+ *
+ * Return value: (nullable): The keyboard layout for the given user or #NULL if using system defaults.  Copy the value if you want to use it long term.
  **/
 const gchar *
 lightdm_user_get_layout (LightDMUser *user)
@@ -470,10 +521,10 @@ lightdm_user_get_layout (LightDMUser *user)
 /**
  * lightdm_user_get_layouts:
  * @user: A #LightDMUser
- * 
+ *
  * Get the configured keyboard layouts for a user.
- * 
- * Return value: (transfer none): A NULL-terminated array of keyboard layouts for the given user.  Copy the values if you want to use them long term.
+ *
+ * Return value: (transfer none) (array zero-terminated=1): A NULL-terminated array of keyboard layouts for the given user.  Copy the values if you want to use them long term.
  **/
 const gchar * const *
 lightdm_user_get_layouts (LightDMUser *user)
@@ -485,10 +536,10 @@ lightdm_user_get_layouts (LightDMUser *user)
 /**
  * lightdm_user_get_session:
  * @user: A #LightDMUser
- * 
+ *
  * Get the session for a user.
- * 
- * Return value: The session for the given user or #NULL if using system defaults.
+ *
+ * Return value: (nullable): The session for the given user or #NULL if using system defaults.
  **/
 const gchar *
 lightdm_user_get_session (LightDMUser *user)
@@ -500,9 +551,9 @@ lightdm_user_get_session (LightDMUser *user)
 /**
  * lightdm_user_get_logged_in:
  * @user: A #LightDMUser
- * 
+ *
  * Check if a user is logged in.
- * 
+ *
  * Return value: #TRUE if the user is currently logged in.
  **/
 gboolean
@@ -515,9 +566,9 @@ lightdm_user_get_logged_in (LightDMUser *user)
 /**
  * lightdm_user_get_has_messages:
  * @user: A #LightDMUser
- * 
+ *
  * Check if a user has waiting messages.
- * 
+ *
  * Return value: #TRUE if the user has waiting messages.
  **/
 gboolean
@@ -530,15 +581,15 @@ lightdm_user_get_has_messages (LightDMUser *user)
 /**
  * lightdm_user_get_uid:
  * @user: A #LightDMUser
- * 
+ *
  * Get the uid of a user.
- * 
+ *
  * Return value: The uid of the given user
  **/
 uid_t
 lightdm_user_get_uid (LightDMUser *user)
 {
-    g_return_val_if_fail (LIGHTDM_IS_USER (user), NULL);
+    g_return_val_if_fail (LIGHTDM_IS_USER (user), (uid_t)-1);
     return common_user_get_uid (GET_USER_PRIVATE (user)->common_user);
 }
 
@@ -573,9 +624,7 @@ lightdm_user_get_property (GObject    *object,
                            GValue     *value,
                            GParamSpec *pspec)
 {
-    LightDMUser *self;
-
-    self = LIGHTDM_USER (object);
+    LightDMUser *self = LIGHTDM_USER (object);
 
     switch (prop_id)
     {
@@ -659,14 +708,14 @@ lightdm_user_class_init (LightDMUserClass *klass)
                                                           "name",
                                                           "Username",
                                                           NULL,
-                                                          G_PARAM_READWRITE));
+                                                          G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_REAL_NAME,
                                      g_param_spec_string ("real-name",
                                                           "real-name",
                                                           "Users real name",
                                                           NULL,
-                                                          G_PARAM_READWRITE));
+                                                          G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_DISPLAY_NAME,
                                      g_param_spec_string ("display-name",
@@ -680,21 +729,21 @@ lightdm_user_class_init (LightDMUserClass *klass)
                                                           "home-directory",
                                                           "Home directory",
                                                           NULL,
-                                                          G_PARAM_READWRITE));
+                                                          G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_IMAGE,
                                      g_param_spec_string ("image",
                                                           "image",
                                                           "Avatar image",
                                                           NULL,
-                                                          G_PARAM_READWRITE));
+                                                          G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_BACKGROUND,
                                      g_param_spec_string ("background",
                                                           "background",
                                                           "User background",
                                                           NULL,
-                                                          G_PARAM_READWRITE));
+                                                          G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_LANGUAGE,
                                      g_param_spec_string ("language",
@@ -729,20 +778,20 @@ lightdm_user_class_init (LightDMUserClass *klass)
                                                            "logged-in",
                                                            "TRUE if the user is currently in a session",
                                                            FALSE,
-                                                           G_PARAM_READWRITE));
+                                                           G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_LOGGED_IN,
                                      g_param_spec_boolean ("has-messages",
                                                            "has-messages",
                                                            "TRUE if the user is has waiting messages",
                                                            FALSE,
-                                                           G_PARAM_READWRITE));
+                                                           G_PARAM_READABLE));
     g_object_class_install_property (object_class,
                                      USER_PROP_UID,
-                                     g_param_spec_string ("uid",
+                                     g_param_spec_uint64 ("uid",
                                                           "uid",
                                                           "User UID",
-                                                          NULL,
+                                                          0, G_MAXUINT64, 0,
                                                           G_PARAM_READABLE));
 
     /**
@@ -752,7 +801,7 @@ lightdm_user_class_init (LightDMUserClass *klass)
      * The ::changed signal gets emitted this user account is modified.
      **/
     user_signals[CHANGED] =
-        g_signal_new ("changed",
+        g_signal_new (LIGHTDM_SIGNAL_USER_CHANGED,
                       G_TYPE_FROM_CLASS (klass),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (LightDMUserClass, changed),
