@@ -33,7 +33,7 @@ typedef struct
     SeatClass parent_class;
 } SeatXVNCClass;
 
-G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeatXVNC, g_object_unref);
+G_DEFINE_AUTOPTR_CLEANUP_FUNC (SeatXVNC, g_object_unref)
 
 GType seat_xvnc_get_type (void);
 
