@@ -5,6 +5,9 @@
 #include <glib-object.h>
 #include <xcb/xcb.h>
 #include <QLightDM/Greeter>
+#include <QLightDM/Power>
+#include <QLightDM/UsersModel>
+#include <QLightDM/SessionsModel>
 #include <QtCore/QSettings>
 #include <QtCore/QDebug>
 #include <QtCore/QCoreApplication>
@@ -15,8 +18,10 @@
 static gchar *greeter_id;
 static QCoreApplication *app = NULL;
 static QSettings *config = NULL;
+static QLightDM::PowerInterface *power = NULL;
 static TestGreeter *greeter = NULL;
 static QLightDM::UsersModel *users_model = NULL;
+static QLightDM::SessionsModel *sessions_model = NULL;
 
 TestGreeter::TestGreeter ()
 {
@@ -48,7 +53,43 @@ void TestGreeter::authenticationComplete ()
 
 void TestGreeter::autologinTimerExpired ()
 {
-    status_notify ("%s AUTOLOGIN-TIMER-EXPIRED", greeter_id);
+}
+
+void TestGreeter::printHints ()
+{
+    if (selectUserHint() != "")
+        status_notify ("%s SELECT-USER-HINT USERNAME=%s", greeter_id, greeter->selectUserHint ().toAscii ().constData ());
+    if (selectGuestHint())
+        status_notify ("%s SELECT-GUEST-HINT", greeter_id);
+    if (lockHint())
+        status_notify ("%s LOCK-HINT", greeter_id);
+    if (!hasGuestAccountHint ())
+        status_notify ("%s HAS-GUEST-ACCOUNT-HINT=FALSE", greeter_id);
+    if (hideUsersHint ())
+        status_notify ("%s HIDE-USERS-HINT", greeter_id);
+    if (showManualLoginHint ())
+        status_notify ("%s SHOW-MANUAL-LOGIN-HINT", greeter_id);
+    if (!showRemoteLoginHint ())
+        status_notify ("%s SHOW-REMOTE-LOGIN-HINT=FALSE", greeter_id);
+    if (autologinUserHint () != "")
+        status_notify ("%s AUTOLOGIN-USER-HINT=%s", greeter_id, autologinUserHint ().toAscii ().constData ());
+    if (autologinGuestHint ())
+        status_notify ("%s AUTOLOGIN-GUEST-HINT", greeter_id);
+    if (autologinSessionHint () != "")
+        status_notify ("%s AUTOLOGIN-SESSION-HINT=%s", greeter_id, autologinSessionHint ().toAscii ().constData ());
+    if (autologinTimeoutHint () != 0)
+        status_notify ("%s AUTOLOGIN-TIMEOUT-HINT=%d", greeter_id, autologinTimeoutHint ());
+}
+
+void TestGreeter::idle ()
+{
+    status_notify ("%s IDLE", greeter_id);
+}
+
+void TestGreeter::reset ()
+{
+    status_notify ("%s RESET", greeter_id);
+    printHints ();
 }
 
 void TestGreeter::userRowsInserted (const QModelIndex & parent, int start, int end)
@@ -77,81 +118,59 @@ signal_cb (int signum)
 }
 
 static void
-request_cb (const gchar *request)
+request_cb (const gchar *name, GHashTable *params)
 {
     gchar *r;
 
-    if (!request)
+    if (!name)
     {
         app->quit ();
         return;
     }
   
-    r = g_strdup_printf ("%s AUTHENTICATE", greeter_id);
-    if (strcmp (request, r) == 0)
-        greeter->authenticate ();
-    g_free (r);
+    if (strcmp (name, "AUTHENTICATE") == 0)
+    {
+        if (g_hash_table_lookup (params, "USERNAME"))
+            greeter->authenticate ((const gchar *) g_hash_table_lookup (params, "USERNAME"));
+        else
+            greeter->authenticate ();
+    }
 
-    r = g_strdup_printf ("%s AUTHENTICATE USERNAME=", greeter_id);
-    if (g_str_has_prefix (request, r))
-        greeter->authenticate (request + strlen (r));
-    g_free (r);
-
-    r = g_strdup_printf ("%s AUTHENTICATE-GUEST", greeter_id);
-    if (strcmp (request, r) == 0)
+    else if (strcmp (name, "AUTHENTICATE-GUEST") == 0)
         greeter->authenticateAsGuest ();
-    g_free (r);
-
-    r = g_strdup_printf ("%s AUTHENTICATE-AUTOLOGIN", greeter_id);
-    if (strcmp (request, r) == 0)
+  
+    else if (strcmp (name, "AUTHENTICATE-AUTOLOGIN") == 0)
         greeter->authenticateAutologin ();
-    g_free (r);
 
-    r = g_strdup_printf ("%s AUTHENTICATE-REMOTE SESSION=", greeter_id);
-    if (g_str_has_prefix (request, r))
-        greeter->authenticateRemote (request + strlen (r), NULL);
-    g_free (r);
+    else if (strcmp (name, "AUTHENTICATE-REMOTE") == 0)
+        greeter->authenticateRemote ((const gchar *) g_hash_table_lookup (params, "SESSION"), NULL);
 
-    r = g_strdup_printf ("%s RESPOND TEXT=\"", greeter_id);
-    if (g_str_has_prefix (request, r))
-    {
-        gchar *text = g_strdup (request + strlen (r));
-        text[strlen (text) - 1] = '\0';
-        greeter->respond (text);
-        g_free (text);
-    }
-    g_free (r);
+    else if (strcmp (name, "RESPOND") == 0)
+        greeter->respond ((const gchar *) g_hash_table_lookup (params, "TEXT"));
 
-    r = g_strdup_printf ("%s CANCEL-AUTHENTICATION", greeter_id);
-    if (strcmp (request, r) == 0)
+    else if (strcmp (name, "CANCEL-AUTHENTICATION") == 0)
         greeter->cancelAuthentication ();
-    g_free (r);
 
-    r = g_strdup_printf ("%s START-SESSION", greeter_id);
-    if (strcmp (request, r) == 0)
+    else if (strcmp (name, "START-SESSION") == 0)
     {
-        if (!greeter->startSessionSync ())
-            status_notify ("%s SESSION-FAILED", greeter_id);
+        if (g_hash_table_lookup (params, "SESSION"))
+        {
+            if (!greeter->startSessionSync ((const gchar *) g_hash_table_lookup (params, "SESSION")))
+                status_notify ("%s SESSION-FAILED ERROR=%s", greeter_id, "FIXME: Exceptions in Qt");
+        }
+        else
+        {
+            if (!greeter->startSessionSync ())
+                status_notify ("%s SESSION-FAILED ERROR=%s", greeter_id, "FIXME: Exceptions in Qt");
+        }
     }
-    g_free (r);
 
-    r = g_strdup_printf ("%s START-SESSION SESSION=", greeter_id);
-    if (g_str_has_prefix (request, r))
-    {
-        if (!greeter->startSessionSync (request + strlen (r)))
-            status_notify ("%s SESSION-FAILED", greeter_id);
-    }
-    g_free (r);
-
-    r = g_strdup_printf ("%s LOG-USER-LIST-LENGTH", greeter_id);
-    if (strcmp (request, r) == 0)
+    else if (strcmp (name, "LOG-USER-LIST-LENGTH") == 0)
         status_notify ("%s LOG-USER-LIST-LENGTH N=%d", greeter_id, users_model->rowCount (QModelIndex ()));
-    g_free (r);
 
-    r = g_strdup_printf ("%s LOG-USER USERNAME=", greeter_id);
-    if (g_str_has_prefix (request, r))
+    else if (strcmp (name, "LOG-USER") == 0)
     {
-        const gchar *username = request + strlen (r);
+        const gchar *username = (const gchar *) g_hash_table_lookup (params, "USERNAME");
         for (int i = 0; i < users_model->rowCount (QModelIndex ()); i++)
         {
             QString name = users_model->data (users_model->index (i, 0), QLightDM::UsersModel::NameRole).toString ();
@@ -159,10 +178,8 @@ request_cb (const gchar *request)
                 status_notify ("%s LOG-USER USERNAME=%s", greeter_id, qPrintable (name));
         }
     }
-    g_free (r);
 
-    r = g_strdup_printf ("%s LOG-USER-LIST", greeter_id);
-    if (strcmp (request, r) == 0)
+    else if (strcmp (name, "LOG-USER-LIST") == 0)
     {
         for (int i = 0; i < users_model->rowCount (QModelIndex ()); i++)
         {
@@ -170,14 +187,70 @@ request_cb (const gchar *request)
             status_notify ("%s LOG-USER USERNAME=%s", greeter_id, qPrintable (name));
         }
     }
-    g_free (r);
+
+    else if (strcmp (name, "LOG-SESSIONS") == 0)
+    {
+        for (int i = 0; i < sessions_model->rowCount (QModelIndex ()); i++)
+        {
+            QString key = sessions_model->data (sessions_model->index (i, 0), QLightDM::SessionsModel::KeyRole).toString ();
+            status_notify ("%s LOG-SESSION KEY=%s", greeter_id, qPrintable (key));
+        }
+    }
+
+    else if (strcmp (name, "GET-CAN-SUSPEND") == 0)
+    {
+        gboolean can_suspend = power->canSuspend ();
+        status_notify ("%s CAN-SUSPEND ALLOWED=%s", greeter_id, can_suspend ? "TRUE" : "FALSE");
+    }
+
+    else if (strcmp (name, "SUSPEND") == 0)
+    {
+        if (!power->suspend ())
+            status_notify ("%s FAIL-SUSPEND", greeter_id);
+    }
+
+    else if (strcmp (name, "GET-CAN-HIBERNATE") == 0)
+    {
+        gboolean can_hibernate = power->canHibernate ();
+        status_notify ("%s CAN-HIBERNATE ALLOWED=%s", greeter_id, can_hibernate ? "TRUE" : "FALSE");
+    }
+
+    else if (strcmp (name, "HIBERNATE") == 0)
+    {
+        if (!power->hibernate ())
+            status_notify ("%s FAIL-HIBERNATE", greeter_id);
+    }
+
+    else if (strcmp (name, "GET-CAN-RESTART") == 0)
+    {
+        gboolean can_restart = power->canRestart ();
+        status_notify ("%s CAN-RESTART ALLOWED=%s", greeter_id, can_restart ? "TRUE" : "FALSE");
+    }
+
+    else if (strcmp (name, "RESTART") == 0)
+    {
+        if (!power->restart ())
+            status_notify ("%s FAIL-RESTART", greeter_id);
+    }
+
+    else if (strcmp (name, "GET-CAN-SHUTDOWN") == 0)
+    {
+        gboolean can_shutdown = power->canShutdown ();
+        status_notify ("%s CAN-SHUTDOWN ALLOWED=%s", greeter_id, can_shutdown ? "TRUE" : "FALSE");
+    }
+
+    else if (strcmp (name, "SHUTDOWN") == 0)
+    {
+        if (!power->shutdown ())
+            status_notify ("%s FAIL-SHUTDOWN", greeter_id);
+    }
 }
 
 int
 main(int argc, char *argv[])
 {
-    gchar *display, *xdg_seat, *xdg_vtnr, *xdg_session_cookie;
-    GString *status_text;   
+    gchar *display, *xdg_seat, *xdg_vtnr, *xdg_session_cookie, *xdg_session_class;
+    g_autoptr(GString) status_text = NULL;
 
 #if !defined(GLIB_VERSION_2_36)
     g_type_init ();
@@ -187,6 +260,7 @@ main(int argc, char *argv[])
     xdg_seat = getenv ("XDG_SEAT");
     xdg_vtnr = getenv ("XDG_VTNR");
     xdg_session_cookie = getenv ("XDG_SESSION_COOKIE");
+    xdg_session_class = getenv ("XDG_SESSION_CLASS");
     if (display)
     {
         if (display[0] == ':')
@@ -197,7 +271,12 @@ main(int argc, char *argv[])
     else
         greeter_id = g_strdup ("GREETER-?");
 
-    status_connect (request_cb);
+    status_connect (request_cb, greeter_id);
+
+    /* Workaround for Qt being confused by libsystem */
+#if QT_VERSION >= QT_VERSION_CHECK (5, 3, 0)
+    QCoreApplication::setSetuidAllowed (true);
+#endif  
 
     app = new QCoreApplication (argc, argv);
 
@@ -212,8 +291,9 @@ main(int argc, char *argv[])
         g_string_append_printf (status_text, " XDG_VTNR=%s", xdg_vtnr);
     if (xdg_session_cookie)
         g_string_append_printf (status_text, " XDG_SESSION_COOKIE=%s", xdg_session_cookie);
-    status_notify (status_text->str);
-    g_string_free (status_text, TRUE);
+    if (xdg_session_class)
+        g_string_append_printf (status_text, " XDG_SESSION_CLASS=%s", xdg_session_class);
+    status_notify ("%s", status_text->str);
 
     config = new QSettings (g_build_filename (getenv ("LIGHTDM_TEST_ROOT"), "script", NULL), QSettings::IniFormat);
 
@@ -228,7 +308,15 @@ main(int argc, char *argv[])
         status_notify ("%s CONNECT-XSERVER", greeter_id);
     }
 
+    power = new QLightDM::PowerInterface();
+
     greeter = new TestGreeter();
+    if (config->value ("test-greeter-config/resettable", "false") == "true")
+    {
+        greeter->setResettable (true);
+        QObject::connect (greeter, SIGNAL(idle()), greeter, SLOT(idle()));
+        QObject::connect (greeter, SIGNAL(reset()), greeter, SLOT(reset()));
+    }
 
     users_model = new QLightDM::UsersModel();
     if (config->value ("test-greeter-config/log-user-changes", "false") == "true")
@@ -237,6 +325,8 @@ main(int argc, char *argv[])
         QObject::connect (users_model, SIGNAL(rowsAboutToBeRemoved(const QModelIndex&, int, int)), greeter, SLOT(userRowsRemoved(const QModelIndex&, int, int)));
     }
 
+    sessions_model = new QLightDM::SessionsModel();
+
     status_notify ("%s CONNECT-TO-DAEMON", greeter_id);
     if (!greeter->connectSync())
     {
@@ -246,20 +336,7 @@ main(int argc, char *argv[])
 
     status_notify ("%s CONNECTED-TO-DAEMON", greeter_id);
 
-    if (greeter->selectUserHint() != "")
-        status_notify ("%s SELECT-USER-HINT USERNAME=%s", greeter_id, greeter->selectUserHint ().toAscii ().constData ());
-    if (greeter->selectGuestHint())
-        status_notify ("%s SELECT-GUEST-HINT", greeter_id);
-    if (greeter->lockHint())
-        status_notify ("%s LOCK-HINT", greeter_id);
-    if (!greeter->hasGuestAccountHint ())
-        status_notify ("%s HAS-GUEST-ACCOUNT-HINT=FALSE", greeter_id);
-    if (greeter->hideUsersHint ())
-        status_notify ("%s HIDE-USERS-HINT", greeter_id);
-    if (greeter->showManualLoginHint ())
-        status_notify ("%s SHOW-MANUAL-LOGIN-HINT", greeter_id);
-    if (!greeter->showRemoteLoginHint ())
-        status_notify ("%s SHOW-REMOTE-LOGIN-HINT=FALSE", greeter_id);
+    greeter->printHints();
 
     return app->exec();
 }
