@@ -9,8 +9,6 @@ static GKeyFile *config;
 int
 main (int argc, char **argv)
 {
-    g_autoptr(GString) status_text = NULL;
-
 #if !defined(GLIB_VERSION_2_36)
     g_type_init ();
 #endif
@@ -26,7 +24,7 @@ main (int argc, char **argv)
         return EXIT_FAILURE;
     }
 
-    status_text = g_string_new ("SCRIPT-HOOK");
+    g_autoptr(GString) status_text = g_string_new ("SCRIPT-HOOK");
     g_string_append_printf (status_text, " %s", argv[1]);
     if (g_getenv ("USER"))
         g_string_append_printf (status_text, " USER=%s", g_getenv ("USER"));
